@@ -8,6 +8,7 @@ import numpy as np
 import warnings
 from astropy.io import fits
 from astropy.time import Time
+from peewee import JOIN
 
 import kaiju
 import kaiju.robotGrid
@@ -216,7 +217,7 @@ class FPSDesign(object):
         else:
             design_field_db = (
                 Design.select(Design.design_id,
-                              Design.design_mode_pk,
+                              Design.design_mode,
                               Field.racen,
                               Field.deccen,
                               Field.position_angle,
@@ -227,11 +228,11 @@ class FPSDesign(object):
                             on=(Field.observatory == Observatory.pk))
                       .where(Design.design_id == self.design_pk))
 
-            self.racen = design_field_db[0].field.racen
-            self.deccen = design_field_db[0].field.deccen
-            self.position_angle = design_field_db[0].field.position_angle
-            self.observatory = design_field_db[0].field.observatory.label
-            self.desmode_label = design_field_db[0].design_mode_pk
+            self.racen = design_field_db.objects()[0].racen
+            self.deccen = design_field_db.objects()[0].deccen
+            self.position_angle = design_field_db.objects()[0].position_angle
+            self.observatory = design_field_db.objects()[0].label
+            self.desmode_label = design_field_db.objects()[0].design_mode.label
 
         # should these be catalogids or carton_to_target?
         self.idtype = idtype
@@ -393,8 +394,8 @@ class FPSDesign(object):
                               Magnitude.gaia_g,
                               Magnitude.rp,
                               Magnitude.h,
-                              Target.delta_ra,
-                              Target.delta_dec,
+                              CartonToTarget.delta_ra,
+                              CartonToTarget.delta_dec,
                               Target.pmra,
                               Target.pmdec,
                               Target.epoch,
@@ -406,7 +407,7 @@ class FPSDesign(object):
                       .join(CartonToTarget)
                       .join(Target)
                       .switch(CartonToTarget)
-                      .join(Magnitude)
+                      .join(Magnitude, JOIN.LEFT_OUTER)
                       .switch(CartonToTarget)
                       .join(Carton)
                       .join(Category)
